<?php

/**
 * @file alter_stubs.inc
 * Provide the most useful alter hooks for plug-ins.
 */

/**
 * Implements hook_comment_view_alter().
 * @see comment_view()
 */
function hex_comment_view_alter(&$build, &$type) {
  hex_alter('comment_view', $build, $type);
}

/**
 * Implements hook_node_view_alter().
 * @see node_view()
 */
function hex_node_view_alter(&$build, &$type) {
  hex_alter('node_view', $build, $type);
}

/**
 * Implements hook_user_view_alter().
 * @see user_view()
 */
function hex_user_view_alter(&$build, &$type) {
  hex_alter('user_view', $build, $type);
}

/**
 * Implements hook_entity_view_alter().
 * @see comment_view()
 * @see node_view()
 * @see user_view()
 */
function hex_entity_view_alter(&$build, &$type) {
  hex_alter('entity_view', $build, $type);
}

/**
 * Implements hook_contextual_links_view_alter().
 * @see contextual_pre_render_links()
 */
function hex_contextual_links_view_alter(&$element, &$items) {
  hex_alter('contextual_links_view', $element, $items);
}

/**
 * Implements hook_html_head_alter().
 * @see drupal_get_html_head()
 */
function hex_html_head_alter(&$elements) {
  hex_alter('html_head', $elements);
}

/**
 * Implements hook_css_alter().
 * @see drupal_get_css()
 */
function hex_css_alter(&$css) {
  hex_alter('css', $css);
}

/**
 * Implements hook_js_alter().
 * @see drupal_get_js()
 */
function hex_js_alter(&$javascript) {
  hex_alter('js', $javascript);
}

/**
 * Implements hook_form_alter().
 * @see drupal_prepare_form()
 *
 * Invokes the following:
 *  - hook_form_hex_alter()
 *  - hook_form_BASE_FORM_ID_hex_alter()
 *  - hook_form_FORM_ID_hex_alter()
 */
function hex_form_alter(&$form, &$form_state, &$form_id) {
  $hooks = array('form');
  if (isset($form_state['build_info']['base_form_id'])) {
    $hooks[] = 'form_' . $form_state['build_info']['base_form_id'];
  }
  $hooks[] = 'form_' . $form_id;
  foreach ($hooks as $hook) {
    hex_alter($hook, $form, $form_state, $form_id);
  }
}

/**
 * Implements hook_page_alter().
 * @see drupal_render_page()
 */
function hex_page_alter(&$page) {
  hex_alter('page', $page);
}

/**
 * Implements hook_element_info_alter().
 * @see element_info()
 */
function hex_element_info_alter(&$cache) {
  hex_alter('element_info', $cache);
}

/**
 * Implements hook_entity_info_alter().
 * @see entity_get_info()
 */
function hex_entity_info_alter(&$entity_info) {
  hex_alter('entity_info', $entity_info);
}

/**
 * Implements hook_image_effect_info_alter().
 * @see image_effect_definitions()
 */
function hex_image_effect_info_alter(&$effects) {
  hex_alter('image_effect_info', $effects);
}

/**
 * Implements hook_image_styles_alter().
 * @see image_styles()
 */
function hex_image_styles_alter(&$styles) {
  hex_alter('image_styles', $styles);
}

/**
 * Implements hook_menu_contextual_links_alter().
 * @see menu_contextual_links()
 */
function hex_menu_contextual_links_alter(&$links, &$router_item, &$root_path) {
  hex_alter('menu_contextual_links', $links, $router_item, $root_path);
}

/**
 * Implements hook_menu_breadcrumb_alter().
 * @see menu_get_active_breadcrumb()
 */
function hex_menu_breadcrumb_alter(&$active_trail, &$item) {
  hex_alter('menu_breadcrumb', $active_trail, $item);
}

/**
 * Implements hook_menu_local_tasks_alter().
 * @see menu_local_tasks()
 */
function hex_menu_local_tasks_alter(&$data, &$router_item, &$root_path) {
  hex_alter('menu_local_tasks', $data, $router_item, $root_path);
}

/**
 * Implements hook_block_view_alter().
 * @see _block_render_blocks()
 */
function hex_block_view_alter(&$array, &$block) {
  hex_alter('block_view', $array, $block);
}

/**
 * Implements hook_theme_registry_alter().
 * @see _theme_build_registry()
 */
function hex_theme_registry_alter(&$cache) {
  hex_alter('theme_registry', $cache);
}

/**
 * implements hook_system_info_alter().
 * @see _system_rebuild_theme_data()
 */
function hex_system_info_alter(&$info, &$theme, $type) {
  hex_alter('system_info', $info, $theme, $type);
}

/**
 * Does the work of giving plugin's the chance to alter data.
 * @see drupal_alter()
 */
function hex_alter($type, &$data, &$context1 = NULL, &$context2 = NULL) {
  $cache = &drupal_static(__FUNCTION__, array());
  if (!isset($cache[$type])) {

    // Ensure HEX_ACTIVE context.
    $context = hex_theme_context_current();
    hex_theme_context(HEX_ACTIVE);

    foreach (hex_path_to_file_multiple($type . '.alter.inc', 'hook_alter') as $file) {
      include_once DRUPAL_ROOT . '/' . $file;
    }

    $cache[$type] = array();
    foreach (hex_active_themes() as $theme) {
      if (function_exists($func = $theme . '_' . $type . '_hex_alter')) {
        $cache[$type][] = $func;
      }
      foreach (hex_plugin_list("$theme.active") as $plugin) {
        if (function_exists($func = $plugin . '_' . $type . '_hex_alter')) {
          $cache[$type][] = $func;
        }
      }
    }

    // Push back previous context.
    hex_theme_context($context);
  }
  foreach ($cache[$type] as $hex_alter) {
    $hex_alter($data, $context1, $context2);
  }
}
