<?php

/**
 * @file build_settings.inc
 * Builds theme settings. Included by Hexagon's cache system.
 * This isn't cpu intensive but it has been placed into the caching system
 * since theme settings rarely change. Placing it here means not including it
 * on every page load.
 */
// Calls hex_auto_type()
include_once HEX_INCLUDES . '/theme_api.inc';

/**
 * Builds theme settings.
 */
function hex_build_settings($ignore_parent_scope = FALSE) {

  $output = new stdClass();
  $output->settings = $output->cascade = array();

  // Global and theme specific settings produce the same default set of options.
  $global = variable_get('theme_settings', array());
  $themes = list_themes();

  foreach (hex_active_themes() as $theme) {
    $settings = array();
    // Saved theme settings.
    foreach (variable_get("theme_{$theme}_settings", $global) as $key => $setting) {
      $settings[hex_fapi_key($key, TRUE)] = $setting;
    }
    // Name spaced .info settings. Used for plug-in specific settings.
    foreach ($themes[$theme]->info as $info_key => $info) {
      if (($pos = strrpos($info_key, '.settings')) !== FALSE) {
        $settings += array(substr($info_key, 0, $pos) => $info);
      }
    }
    // General .info settings.
    if (isset($themes[$theme]->info['settings'])) {
      $settings += $themes[$theme]->info['settings'];
    }

    // Flatten all arrays. Will be rebuilt below.
    // This will allow more precise overriding behavior.
    $ai = new RecursiveArrayIterator($settings);
    $it = new RecursiveIteratorIterator($ai, RecursiveIteratorIterator::SELF_FIRST);
    $settings = array();
    foreach ($it as $key => $setting) {
      $keys[$it->getDepth()] = $key;
      $keys = array_splice($keys, 0, $it->getDepth() + 1);
      if (!is_array($setting)) {
        $set_key = implode('.', $keys);
        $settings += array($set_key => $setting);
      }
    }

    // Add to $output
    reset($settings);
    $output->settings[$theme] = array();
    while (list($setting_key, $setting) = each($settings)) {
      // Check for the parent values.
      if (!$ignore_parent_scope) {
        $pkey = $setting_key;
        while (($pos = strrpos($pkey, ':')) !== FALSE) {
          $pkey = substr($pkey, 0, $pos);
          $pval = &$settings[$pkey];
          $pval = hex_auto_type($pval);
          if (empty($pval)) {
            $setting = NULL;
            break;
          }
        }
      }

      // Recreate flattened array.
      $sset = &$settings;
      $last = substr($setting_key, strrpos($setting_key, '.') + 1);
      foreach (explode('.', $setting_key) as $i => $skey) {
        $sval  = $skey == $last ? $setting : array();
        $sset += array($skey => $sval);
        $sset  = &$sset[$skey];
      }
      // Bring back the internal pointer because modifying $settings can reset
      // the internal pointer and each() will end up in an infinite loop.
      foreach ($settings as $k => $s) { if ($k == $setting_key) { break; } }

      $setting = hex_auto_type($setting);
      $output->settings[$theme][$setting_key] = $setting;
      if (isset($setting)) {
        $output->cascade[$setting_key] = $theme;
      }
    }
  }

  return $output;
}
