<?php

/**
 * @file include_vars.inc
 * Does the work of including hook.vars.inc files.
 *
 * When any of the following files are detected for a specific hook, this file
 * will be included in the theme registry:
 *
 * - [ HOOK ].vars.inc
 * - [ HOOK ].[ ACTIVE-THEME ].vars.inc
 * - [ HOOK ].[ func | tpl ].vars.inc
 * - [ HOOK ].[ ACTIVE-THEME ].[ func | tpl ].vars.inc
 * - [ HOOK--PATTERN ].vars.inc
 * - [ HOOK--PATTERN ].[ ACTIVE-THEME ].vars.inc
 * - [ HOOK--PATTERN ].[ func | tpl ].vars.inc
 * - [ HOOK--PATTERN ].[ ACTIVE-THEME ].[ func | tpl ].vars.inc
 */

/**
 * A custom variable process function with the sole purpose of including
 * hook.vars.inc and/or hook--suggestion.vars.inc files.
 */
function hex_variable_include_process(&$variables, $hook) {

  // Checking suggestions to work around a core limitation of preventing
  // preprocess functions *specific to a suggestion* from being processed,
  // e.g. mytheme_preprocess_hook__suggestion(). Although this does not
  // allow the functions itself, hook--suggestion.vars.inc files will be
  // loaded and processed in addition to a base hook.vars.inc when available.

  $suggestions = array();
  if (!empty($variables['theme_hook_suggestions'])) {
    $suggestions = $variables['theme_hook_suggestions'];
  }
  if (!empty($variables['theme_hook_suggestion'])) {
    $suggestions[] = $variables['theme_hook_suggestion'];
  }
  if (!empty($suggestions)) {
    foreach (array_reverse($suggestions) as $suggestion) {
      // hex_theme_hook_info() has access to all the hooks.
      // Used here to check for its existence.
      if (hex_theme_hook_info($suggestion)) {
        $hook = $suggestion;
        break;
      }
    }
  }
  foreach (hex_theme_hook_info($hook)->variable_includes as $variable_include) {
    _hex_var_include($variables, $hook, $variable_include);
  }
}

/**
 * Includes the hook.vars.inc file and extracts the variables.
 */
function _hex_var_include(&$variables, $hook, $variable_include) {
  // Allow both common spellings.
  $vars = &$variables;
  // Extract the variables to a local namespace. This is not expensive.
  extract($variables, EXTR_REFS + EXTR_SKIP);
  include DRUPAL_ROOT . '/' . $variable_include;
}
