<?php

/**
 * @file theme_api.inc
 * General administrative helper functions when working with the theme api
 * form or settings.
 */
// Calls hex_build_settings().
include_once HEX_INCLUDES . '/build_settings.inc';

/**
 * Same as hex_settings but it does not check for parent scopes, the default
 * $theme is HEX_THEMEAPI and it is not cached. This should be used instead of
 * hex_setting() while in the theme settings form.
 *
 * @see hex_setting()
 */
function hex_themeapi_setting($name = NULL, $default = NULL, $theme = HEX_THEMEAPI, $ignore_parent_scope = TRUE) {
  $settings = hex_build_settings($ignore_parent_scope);

  if ($theme === HEX_ACTIVE || $theme === HEX_THEMEAPI) {
    $theme = hex_active_theme($theme);
  }
  elseif ($theme == HEX_CASCADE && !empty($settings->cascade[$name])) {
    $theme = $settings->cascade[$name];
  }

  return isset($settings->settings[$theme][$name]) ? $settings->settings[$theme][$name] : $default;
}

/**
 * Wrap this function for Form API keys that contain dots and colons since it
 * can cause problems.
 * 
 * @param $key
 *  The key.
 * @param $revert
 *  Revert to their original dots and colons.
 */
function hex_fapi_key($key, $revert = FALSE) {
  switch ($revert) {
    // Dot seen as an array "key" and colon for parent conditions or "scope".
    case FALSE : return str_replace(array('.', ':'), array('__key__', '__scp__'), $key);
    case TRUE  : return str_replace(array('__key__', '__scp__'), array('.', ':'), $key);
  }
}

/**
 * Casts strings into constants and integers/floats.
 */
function hex_auto_type($value) {
  if (is_string($value) && is_numeric($value)) {
    $value = ctype_digit($value) ? (int) $value : (float) $value;
  }
  elseif (is_string($value) && defined(strtoupper($value))) {
    $value = constant(strtoupper($value));
  }

  return $value;
}

