<?php

/**
 * @file template.php
 * Contains the base functionality for Hexagon and includes other files when
 * necessary.
 */
define('HEX_ROOT',     DRUPAL_ROOT . '/' . drupal_get_path('theme', 'hex'));
define('HEX_INCLUDES', HEX_ROOT . '/includes');

_hex_initialize();

/**
 * Initializes the theme.
 */
function _hex_initialize() {

  include_once HEX_INCLUDES . '/meta_theme.inc';
  include_once HEX_INCLUDES . '/meta_plugin.inc';
  include_once HEX_INCLUDES . '/meta_files.inc';
  include_once HEX_INCLUDES . '/alter/alter_stubs.inc';

  // Hold the theme_key.
  $GLOBALS['theme_static'] = $GLOBALS['theme_key'];

  // Load and initialize the theme and plug-ins only if Hexagon or any of its
  // child themes are active. This conditional loading eliminates any possible
  // conflicts when inside the theme settings form while this theme or any child
  // is not currently active.

  if (!in_array('hex', hex_active_themes(HEX_CURRENT_PAGE))) {
    return;
  }

  if (hex_setting('development_mode:disable_theme_caching', 0, HEX_ACTIVE)) {
    // Clear theme .info data and registry.
    system_rebuild_theme_data();
    drupal_theme_rebuild();
  }
  if (cache_get('theme_registry:' . hex_active_theme(), 'cache') === FALSE) {
    // Follow the registry and clear hex specific caches.
    hex_clear_caches();
  }

  // Initialize.
  foreach (hex_active_themes() as $theme) {
    if (function_exists($theme . '_initialize')) {
      call_user_func($theme . '_initialize');
    }
    foreach (hex_plugin_list("$theme.active") as $plugin) {
      if (file_exists($file = hex_path('plugin', $plugin) . "/$plugin.plug.inc")) {
        include_once DRUPAL_ROOT . '/' . $file;
      }
      if (function_exists($plugin . '_initialize')) {
        call_user_func($plugin . '_initialize');
      }
    }
  }
}

/**
 * Clears all caches held by Hexagon.
 */
function hex_clear_caches() {
  drupal_static_reset('_hex_cache');
  cache_clear_all('hex_cache', 'cache', TRUE);
}

/**
 * Semiautomated caching. This is private. Don't call directly.
 *
 * Gets the cache for the given key. If none is available, a file name based
 * on the key is included. Then a function for building the cache data is
 * called (also named based on the key). The returned data is stored in the
 * cache and the data is returned.
 *
 * @param $cache_key
 *  The key used to store and retrieve the cache.
 */
function _hex_cache($cache_key) {
  $cache = &drupal_static(__FUNCTION__, array());
  $cache_id = "hex_cache:$cache_key:" . hex_active_theme();

  if (!isset($cache[$cache_id])) {
    if ($cache_get = cache_get($cache_id)) {
      $cache[$cache_id] = $cache_get->data;
    }
    else {
      include_once "includes/build_$cache_key.inc";
      timer_start($cache_id);

      $cache[$cache_id] = call_user_func("hex_build_$cache_key");
      cache_set($cache_id, $cache[$cache_id]);

      timer_stop($cache_id);
      hex_notify('Created and saved cache id !id in !timer milliseconds.',
                 array('!id' => $cache_id, '!timer' => timer_read($cache_id)),
                 'debug');
    }
  }

  return $cache[$cache_id];
}
